@@ -88,6 +88,14 @@ T = DEFAULT_GRADIENT_TRACER
             @test J(x -> clamp(x[1], x[2], 1.0), rand(2)) == [1 1]
             @test J(x -> clamp(x[1], 0.0, x[2]), rand(2)) == [1 1]
             @test J(x -> clamp(x[1], x[2], x[3]), rand(3)) == [1 1 1]
+
+            @test J(x -> fma(x, 1.0, 1.0), rand()) == [1;;]
+            @test J(x -> fma(1.0, x, 1.0), rand()) == [1;;]
+            @test J(x -> fma(1.0, 1.0, x), rand()) == [1;;]
+            @test J(x -> fma(x[1], x[2], 1.0), rand(2)) == [1 1]
+            @test J(x -> fma(x[1], 1.0, x[2]), rand(2)) == [1 1]
+            @test J(x -> fma(1.0, x[1], x[2]), rand(2)) == [1 1]
+            @test J(x -> fma(x[1], x[2], x[3]), rand(3)) == [1 1 1]
         end
 
         @testset "Random" begin
@@ -298,6 +306,51 @@ end
             @test J(x -> clamp(x[1], x[2], x[3]), [0.5, 0.0, 1.0]) == [1 0 0]
             @test J(x -> clamp(x[1], x[2], x[3]), [0.5, 0.6, 1.0]) == [0 1 0]
             @test J(x -> clamp(x[1], x[2], x[3]), [0.5, 0.0, 0.4]) == [0 0 1]
+
+            @test J(x -> fma(x, 1.0, 1.0), 1.0) == [1;;]
+            @test J(x -> fma(1.0, x, 1.0), 1.0) == [1;;]
+            @test J(x -> fma(1.0, 1.0, x), 1.0) == [1;;]
+            @test J(x -> fma(x, 0.0, 1.0), 1.0) == [0;;]
+            @test J(x -> fma(0.0, x, 1.0), 1.0) == [0;;]
+            @test J(x -> fma(0.0, 1.0, x), 1.0) == [1;;]
+            @test J(x -> fma(x, 1.0, 0.0), 1.0) == [1;;]
+            @test J(x -> fma(1.0, x, 0.0), 1.0) == [1;;]
+            @test J(x -> fma(1.0, 0.0, x), 1.0) == [1;;]
+            @test J(x -> fma(x, 0.0, 0.0), 1.0) == [0;;]
+            @test J(x -> fma(0.0, x, 0.0), 1.0) == [0;;]
+            @test J(x -> fma(0.0, 0.0, x), 1.0) == [1;;]
+            @test J(x -> fma(x[1], x[2], 1.0), [1.0, 1.0]) == [1 1]
+            @test J(x -> fma(x[1], 1.0, x[2]), [1.0, 1.0]) == [1 1]
+            @test J(x -> fma(1.0, x[1], x[2]), [1.0, 1.0]) == [1 1]
+            @test J(x -> fma(x[1], x[2], 1.0), [0.0, 1.0]) == [1 0]
+            @test J(x -> fma(x[1], 1.0, x[2]), [0.0, 1.0]) == [1 1]
+            @test J(x -> fma(1.0, x[1], x[2]), [0.0, 1.0]) == [1 1]
+            @test J(x -> fma(x[1], x[2], 1.0), [1.0, 0.0]) == [0 1]
+            @test J(x -> fma(x[1], 1.0, x[2]), [1.0, 0.0]) == [1 1]
+            @test J(x -> fma(1.0, x[1], x[2]), [1.0, 0.0]) == [1 1]
+            @test J(x -> fma(x[1], x[2], 1.0), [0.0, 0.0]) == [0 0]
+            @test J(x -> fma(x[1], 1.0, x[2]), [0.0, 0.0]) == [1 1]
+            @test J(x -> fma(1.0, x[1], x[2]), [0.0, 0.0]) == [1 1]
+            @test J(x -> fma(x[1], x[2], 0.0), [1.0, 1.0]) == [1 1]
+            @test J(x -> fma(x[1], 0.0, x[2]), [1.0, 1.0]) == [0 1]
+            @test J(x -> fma(0.0, x[1], x[2]), [1.0, 1.0]) == [0 1]
+            @test J(x -> fma(x[1], x[2], 0.0), [0.0, 1.0]) == [1 0]
+            @test J(x -> fma(x[1], 0.0, x[2]), [0.0, 1.0]) == [0 1]
+            @test J(x -> fma(0.0, x[1], x[2]), [0.0, 1.0]) == [0 1]
+            @test J(x -> fma(x[1], x[2], 0.0), [1.0, 0.0]) == [0 1]
+            @test J(x -> fma(x[1], 0.0, x[2]), [1.0, 0.0]) == [0 1]
+            @test J(x -> fma(0.0, x[1], x[2]), [1.0, 0.0]) == [0 1]
+            @test J(x -> fma(x[1], x[2], 0.0), [0.0, 0.0]) == [0 0]
+            @test J(x -> fma(x[1], 0.0, x[2]), [0.0, 0.0]) == [0 1]
+            @test J(x -> fma(0.0, x[1], x[2]), [0.0, 0.0]) == [0 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [0.0, 0.0, 0.0]) == [0 0 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [1.0, 0.0, 0.0]) == [0 1 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [0.0, 1.0, 0.0]) == [1 0 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [1.0, 1.0, 0.0]) == [1 1 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [0.0, 0.0, 1.0]) == [0 0 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [1.0, 0.0, 1.0]) == [0 1 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [0.0, 1.0, 1.0]) == [1 0 1]
+            @test J(x -> fma(x[1], x[2], x[3]), [1.0, 1.0, 1.0]) == [1 1 1]
         end
 
         @testset "Random" begin
